@@ -221,17 +221,26 @@ gboolean update_minutes(gpointer data)
   struct tm *locTime;
   gchar timeString[45];
   osso_return_t ret;
-
+  
   locTime=localtime(&curTime);
   if ((locTime->tm_min!=statusbar_plugin->previous)||(statusbar_plugin->updated))
   {
+  	cookie_t *list,*iter;
+  	
     statusbar_plugin->curColour=statusbar_plugin->fontColour;
     if (statusbar_plugin->alarms)
     {
-    	cookie_t *list,*iter;
-    	
 		list = alarm_event_query(curTime, curTime + statusbar_plugin->alarm2Time*60*60, 0, 0);
-		if ((list != NULL) && (list[0] != (cookie_t) 0))
+
+		if (list == NULL)
+		{
+			g_debug("alarm_event_query failed");
+		}
+		else if (list[0] == (cookie_t) 0)
+		{
+			free(list);
+		}
+		else
 		{
 			for (iter = list; *iter != (cookie_t) 0; iter++) {
 				alarm_event_t* alarm=alarm_event_get(*iter);
@@ -242,10 +251,19 @@ gboolean update_minutes(gpointer data)
 				}
 				alarm_event_free(alarm);
 			}
+			free(list);
 		}
-
+		
 		list = alarm_event_query(curTime, curTime + statusbar_plugin->alarm1Time*60*60, 0, 0);
-		if ((list != NULL) && (list[0] == (cookie_t) 0))
+		if (list == NULL)
+		{
+			g_debug("alarm_event_query failed");
+		}
+		else if (list[0] == (cookie_t) 0)
+		{
+			free(list);
+		}
+		else
 		{
 			for (iter = list; *iter != (cookie_t) 0; iter++) {
 				alarm_event_t* alarm=alarm_event_get(*iter);
@@ -256,8 +274,8 @@ gboolean update_minutes(gpointer data)
 				}
 				alarm_event_free(alarm);
 			}
+			free(list);
 		}
-		free(list);
     }
 
     ret = osso_rpc_async_run(statusbar_plugin->osso,
